Enum actix_session::SessionStatus [−][src]
pub enum SessionStatus {
Changed,
Purged,
Renewed,
Unchanged,
}Expand description
Status of a Session.
Variants
Session has been updated and requires a new persist operation.
Session is flagged for deletion and should be removed from client and server.
Most operations on the session after purge flag is set should have no effect.
Session is flagged for refresh.
For example, when using a backend that has a TTL (time-to-live) expiry on the session entry, the session will be refreshed even if no data inside it has changed. The client may also be notified of the refresh.
Session is unchanged from when last seen (if exists).
This state also captures new (previously unissued) sessions such as a user’s first site visit.