Module actix_session::storage
source · Expand description
Pluggable storage backends for session state.
Structs
- CookieSessionStore
cookie-sessionUse the session key, stored in the session cookie, as storage backend for the session state. - RedisActorSessionStore
redis-actor-sessionUse Redis as session storage backend. - RedisActorSessionStoreBuilder
redis-actor-sessionA fluent builder to construct aRedisActorSessionStoreinstance with custom configuration parameters. - RedisSessionStore
redis-rs-sessionUse Redis as session storage backend. - RedisSessionStoreBuilder
redis-rs-sessionA fluent builder to construct aRedisSessionStoreinstance with custom configuration parameters. - A session key, the string stored in a client-side cookie to associate a user with its session state on the backend.
Enums
- Possible failures modes for
SessionStore::load. - Possible failures modes for
SessionStore::save. - Possible failures modes for
SessionStore::update.
Traits
- The interface to retrieve and save the current session data from/to the chosen storage backend.